@@ -11,12 +11,12 @@
 #' Nominatim database or they can be downloaded from the
 #' \href{https://nominatim.org/2020/10/21/photon-country-extracts.html}{Photon download server}.
 #' If you want to download pre-built search indices, simply provide a
-#' \code{country} string during initialization or use the
+#' \code{region} string during initialization or use the
 #' \code{$download_data} method. Pre-built search indices do not come with
 #' support for structured geocoding.
 #'
 #' If you want to build from Nominatim, do not
-#' provide a country string and use the \code{$import} method. See
+#' provide a region string and use the \code{$import()} method. See
 #' \code{vignette("nominatim-import", package = "photon")} for details on how
 #' to import from Nominatim.
 #'
@@ -27,12 +27,12 @@
 #' @export
 #' @import R6
 #'
-#' @examples
-#' \donttest{if (has_java("11")) {
+#' @examplesIf getFromNamespace("is_online", "photon")("graphhopper.com") && getFromNamespace("photon_run_examples", "photon")()
+#' if (has_java("11")) {
 #' dir <- file.path(tempdir(), "photon")
 #'
 #' # start a new instance using a Monaco extract
-#' photon <- new_photon(path = dir, country = "Monaco")
+#' photon <- new_photon(path = dir, region = "Andorra")
 #'
 #' # start a new instance with an older photon version
 #' photon <- new_photon(path = dir, photon_version = "0.4.1", opensearch = FALSE)
@@ -45,7 +45,7 @@
 #' photon <- new_photon(path = dir, opensearch = TRUE)
 #' photon$import(photon_options = cmd_options(port = 29146, password = "pgpass"))}
 #'
-#' photon$purge(ask = FALSE)}
+#' photon$purge(ask = FALSE)
 photon_local <- R6::R6Class(
   inherit = photon,
   classname = "photon_local",
@@ -68,32 +68,17 @@ photon_local <- R6::R6Class(
     #' releases can be found here: \url{https://github.com/komoot/photon/releases/}.
     #' Ignored if \code{jar} is given. If \code{NULL}, uses the latest known
     #' version (Currently: `r get_latest_photon()`).
-    #' @param country Character string that can be identified by
-    #' \code{\link[countrycode]{countryname}} as a country. An extract for this
-    #' country will be downloaded. If \code{"planet"}, downloads a global search
-    #' index.
-    #' @param date Character string or date-time object used to specify the creation
-    #' date of the search index. If \code{"latest"}, will download the file tagged
-    #' with "latest". If a character string, the value should be parseable by
-    #' \code{\link{as.POSIXct}}. If \code{exact = FALSE}, the input value is
-    #' compared to all available dates and the closest date will be selected.
-    #' Otherwise, a file will be selected that exactly matches the input to
-    #' \code{date}.
-    #' @param exact If \code{TRUE}, exactly matches the \code{date}. Otherwise,
-    #' selects the date with lowest difference to the \code{date} parameter.
-    #' @param section Subdirectory of the download server from which to select a
-    #' search index. If \code{"experimental"}, selects a dump made for the master
-    #' version of photon. If \code{"archived"}, selects a dump made for an older
-    #' version of photon. If \code{NULL} (or any arbitrary string), selects a
-    #' dump made for the current release. Defaults to \code{NULL}.
-    #' @param opensearch Superseded for photon versions >= 0.7.0. If \code{TRUE},
+    #' @param region Character string that identifies a region or country. An
+    #' extract for this region will be downloaded. If \code{"planet"}, downloads
+    #' a global extract (see note). Run \code{list_regions()} to get an overview
+    #' of available regions. You can specify countries using any code that can
+    #' be translated by \code{\link[countrycode]{countrycode}}.
+    #' @param opensearch Deprecated for photon versions >= 1.0.0 and superseded
+    #' for photon versions >= 0.7.0. If \code{TRUE},
     #' attempts to download the OpenSearch version of photon. OpenSearch-based
-    #' photon supports structrued geocoding. Readily available OpenSearch
-    #' photon executables are only offered since photon version 0.6.0. For
-    #' earlier versions, you need to build from source using gradle. In this
-    #' case, if \code{TRUE}, will look for an OpenSearch version of photon in
-    #' the specified path. Since photon version 0.7.0, OpenSearch is the
-    #' recommended option. Defaults to \code{TRUE}.
+    #' photon supports structured geocoding. If \code{FALSE}, falls back to
+    #' ElasticSearch. Since photon 0.7.0, OpenSearch is the default and since
+    #' 1.0.0, ElasticSearch is not supported anymore.
     #' @param mount If \code{TRUE}, mounts the object to the session so that
     #' functions like \code{\link{geocode}} automatically detect the new
     #' instance. If \code{FALSE}, initializies the instance but doesn't mount
@@ -102,16 +87,15 @@ photon_local <- R6::R6Class(
     #' search indices when initializing a new instance. Defaults to
     #' \code{FALSE}.
     #' @param quiet If \code{TRUE}, suppresses all informative messages.
+    #' @param country Deprecated since photon 1.0.0. Use \code{region} instead.
     initialize = function(path,
                           photon_version = NULL,
-                          country = NULL,
-                          date = "latest",
-                          exact = FALSE,
-                          section = "experimental",
+                          region = NULL,
                           opensearch = TRUE,
                           mount = TRUE,
                           overwrite = FALSE,
-                          quiet = FALSE) {
+                          quiet = FALSE,
+                          country = NULL) {
       assert_flag(quiet)
       assert_flag(opensearch)
       check_jdk_version("11", quiet = quiet)
@@ -126,10 +110,7 @@ photon_local <- R6::R6Class(
       setup_photon_directory(
         path,
         photon_version,
-        country = country,
-        date = date,
-        exact = exact,
-        section = section,
+        region = region,
         opensearch = opensearch,
         overwrite = overwrite,
         quiet = quiet
@@ -141,7 +122,7 @@ photon_local <- R6::R6Class(
       private$opensearch <- opensearch
 
       meta <- private$get_metadata(quiet = quiet)
-      private$country <- meta$country
+      private$region <- meta$region
       private$date <- meta$date
       if (mount) self$mount()
       invisible(self)
@@ -157,7 +138,7 @@ photon_local <- R6::R6Class(
 
     #' @description
     #' Retrieve metadata about the java and photon version used as well
-    #' as the country and creation date of the search index.
+    #' as the region and creation date of the search index.
     #' @return A list containing the java version, the photon version, and
     #' if applicable, the spatial and temporal coverage of the search index.
     info = function() {
@@ -169,9 +150,18 @@ photon_local <- R6::R6Class(
     #' Print the default arguments to the R console. This can be helpful to
     #' get a list of additional photon arguments for \code{$start()} or
     #' \code{$import()}.
+    #' @param cmd A command for which to display the help page. Must be one
+    #' of \code{"start"}, \code{"import"}, \code{"update"}, \code{"update-init"},
+    #' or \code{"dump-nominatim-db"}. Defaults to \code{"start"}.
     #' @return Nothing, but prints to the console.
-    help = function() {
-      cat(run_photon(self, private, mode = "help", photon_opts = "-h")$stdout)
+    help = function(cmd = "start") {
+      cmd <- switch(cmd, start = "serve", cmd)
+      cat(run_photon(
+        self,
+        private,
+        mode = "help",
+        photon_opts = c(cmd, "-h")
+      )$stdout)
     },
 
     #' @description
@@ -209,29 +199,19 @@ photon_local <- R6::R6Class(
     #' @param database Postgres database name. Defaults to \code{"nominatim"}.
     #' @param user Postgres database user. Defaults to \code{"nominatim"}.
     #' @param password Postgres database password. Defaults to \code{""}.
-    #' @param structured If \code{TRUE}, enables structured query support when
-    #' importing the database. This allows the usage of
-    #' \code{\link{structured}}. Structured queries are only supported in the
-    #' OpenSearch version of photon. See section "OpenSearch" above. Defaults
-    #' to \code{FALSE}.
-    #' @param update If \code{TRUE}, fetches updates from the Nominatim database,
-    #' updating the search index without offering an API. If \code{FALSE},
-    #' imports the database an deletes the previous index. Defaults to
-    #' \code{FALSE}.
-    #' @param enable_update_api If \code{TRUE}, enables an additional
-    #' endpoint \code{/nominatim-update}, which allows updates from
-    #' Nominatim databases.
+    #' @param json If \code{TRUE} and a JSON dump is present in the photon
+    #' directory, imports from a JSON dump. Otherwise, tries to import from
+    #' Nominatim.
     #' @param languages Character vector specifying the languages to import
     #' from the Nominatim databases. Defaults to English, French, German,
     #' and Italian.
     #' @param countries Character vector specifying the country codes to
     #' import from the Nominatim database. Defaults to all country codes.
+    #' @param full_geometries Add the full geometry for each place if
+    #' available. Considerably increases the size of the photon database.
     #' @param extra_tags Character vector specifying extra OSM tags to import
     #' from the Nominatim database. These tags are used to augment geocoding
     #' results. Defaults to \code{NULL}.
-    #' @param json If \code{TRUE}, dumps the imported Nominatim database to
-    #' a JSON file and returns the path to the output file. Defaults to
-    #' \code{FALSE}.
     #' @param timeout Time in seconds before the java process aborts. Defaults
     #' to 60 seconds.
     #' @param java_opts Character vector of further flags passed on to the
@@ -239,21 +219,28 @@ photon_local <- R6::R6Class(
     #' @param photon_opts Character vector of further flags passed on to the
     #' photon jar in the java command. See \code{\link{cmd_options}} for a
     #' helper function.
+    #' @param structured Deprecated since v1.0.0. Structured geocoding is
+    #' enabled by default now. For earlier versions, use \code{photon_opts}.
+    #' @param update Deprecated since v1.0.0. Updates are done using a distinct
+    #' command now. For earlier versions, use \code{photon_opts}.
+    #' @param enable_update_api Deprecated since v1.0.0. For earlier versions,
+    #' use \code{photon_opts}.
     import = function(host = "127.0.0.1",
                       port = 5432,
                       database = "nominatim",
                       user = "nominatim",
                       password = "",
-                      structured = FALSE,
-                      update = FALSE,
-                      enable_update_api = FALSE,
+                      json = FALSE,
                       languages = c("en", "fr", "de", "it"),
                       countries = NULL,
+                      full_geometries = FALSE,
                       extra_tags = NULL,
-                      json = FALSE,
                       timeout = 60,
                       java_opts = NULL,
-                      photon_opts = NULL) {
+                      photon_opts = NULL,
+                      structured = NULL,
+                      update = NULL,
+                      enable_update_api = NULL) {
       assert_vector(host, "character", size = 1)
       assert_vector(database, "character", size = 1)
       assert_vector(user, "character", size = 1)
@@ -264,38 +251,41 @@ photon_local <- R6::R6Class(
       assert_vector(timeout, "numeric", size = 1)
       assert_vector(java_opts, "character", null = TRUE)
       assert_vector(photon_opts, "character", null = TRUE)
-      assert_flag(structured)
-      assert_flag(update)
-      assert_flag(enable_update_api)
       assert_flag(json)
 
-      if (structured && !private$opensearch) {
-        cli::cli_warn(paste( # nocov start
-          "Structured queries are only supported for OpenSearch photon.",
-          "Setting {.code structured = FALSE}."
-        ), class = "structured_elasticsearch_error")
-        structured <- FALSE
-      } # nocov end
+      deprecated(structured, "1.0.0", "Use argument `photon_opts` instead.")
+      deprecated(update, "1.0.0", "Use argument `photon_opts` instead.")
+      deprecated(enable_update_api, "1.0.0", "Use argument `photon_opts` instead.")
+
+      json_path <- NULL
+      if (json) {
+        json_path <- private$json_path %||%
+          ph_stop(c(
+            "No JSON dump found.",
+            "i" = "Download a database using $download_data(json = TRUE)"
+          ), class = "import_no_json")
+      }
+
+      countries <- try_iso2(countries)
+      java_opts <- cmd_options(java_opts)
+      photon_opts <- cmd_options(photon_opts)
 
       popts <- cmd_options(
-        nominatim_import = TRUE,
+        import_file = json_path,
         host = host,
         port = port,
         database = database,
         user = user,
         password = password,
-        structured = structured,
-        nominatim_update = update,
-        enable_update_api = enable_update_api,
         languages = languages,
-        country_codes = countries,
-        extra_tags = extra_tags,
-        json = json
+        country_codes = format_csv(countries),
+        extra_tags = extra_tags
       )
 
       run_photon(
         self, private,
         mode = "import",
+        json_path = json_path,
         java_opts = java_opts,
         photon_opts = c(popts, photon_opts)
       )
@@ -315,6 +305,16 @@ photon_local <- R6::R6Class(
     #' Defaults to \code{FALSE}.
     #' @param timeout Time in seconds before the java process aborts. Defaults
     #' to 60 seconds.
+    #' @param countries Character vector of countries to import. By default,
+    #' all countries in the database are imported.
+    #' @param threads Number of threads in parallel. Defaults to 1.
+    #' @param query_timeout Time in seconds after which to cancel queries
+    #' to Photon. Defaults to 7 seconds.
+    #' @param max_results Maximum number of results returned to
+    #' \code{\link{geocode}} and \code{\link{structured}}. Defaults to
+    #' 50.
+    #' @param max_reverse_results Maximum number of results returned to
+    #' \code{\link{reverse}}. Defaults to 50.
     #' @param java_opts Character vector of further flags passed on to the
     #' \code{java} command.
     #' @param photon_opts Character vector of further flags passed on to the
@@ -330,6 +330,11 @@ photon_local <- R6::R6Class(
                      port = "2322",
                      ssl = FALSE,
                      timeout = 60,
+                     countries = NULL,
+                     threads = 1,
+                     query_timeout = NULL,
+                     max_results = NULL,
+                     max_reverse_results = NULL,
                      java_opts = NULL,
                      photon_opts = NULL) {
       assert_vector(host, "character")
@@ -351,7 +356,18 @@ photon_local <- R6::R6Class(
         )
       }
 
-      popts <- cmd_options(listen_ip = host, listen_port = port)
+      countries <- try_iso2(countries)
+      java_opts <- cmd_options(java_opts)
+      photon_opts <- cmd_options(photon_opts)
+      popts <- cmd_options(
+        listen_ip = host,
+        listen_port = port,
+        countries = format_csv(countries),
+        j = threads,
+        query_timeout = query_timeout,
+        max_results = max_results,
+        max_reverse_results = max_reverse_results
+      )
       cleanup <- function(e) self$stop()
       withCallingHandlers(
         run_photon(
@@ -376,39 +392,49 @@ photon_local <- R6::R6Class(
     },
 
     #' @description
-    #' Downloads a search index using \code{\link{download_searchindex}}.
-    #' @param country Character string that can be identified by
-    #' \code{\link[countrycode]{countryname}} as a country. An extract for this
-    #' country will be downloaded. If \code{"planet"}, downloads a global search
-    #' index.
-    #' @param date Character string or date-time object used to specify the creation
-    #' date of the search index. If \code{"latest"}, will download the file tagged
-    #' with "latest". If a character string, the value should be parseable by
-    #' \code{\link{as.POSIXct}}. If \code{exact = FALSE}, the input value is
-    #' compared to all available dates and the closest date will be selected.
-    #' Otherwise, a file will be selected that exactly matches the input to
-    #' \code{date}.
-    #' @param exact If \code{TRUE}, exactly matches the \code{date}. Otherwise,
-    #' selects the date with lowest difference to the \code{date} parameter.
-    #' @param section Subdirectory of the download server from which to select a
-    #' search index. If \code{"experimental"}, selects a dump made for the master
-    #' version of photon. If \code{"archived"}, selects a dump made for an older
-    #' version of photon. If \code{NULL} (or any arbitrary string), selects a
-    #' dump made for the current release. Defaults to \code{NULL}.
-    download_data = function(country,
-                             date = "latest",
-                             exact = FALSE,
-                             section = "experimental") {
-      archive_path <- download_searchindex(
+    #' Returns information from a live server about the photon version used
+    #' and the date of data import.
+    #'
+    #' @returns A list containing four elements:
+    #' \itemize{
+    #'  \strong{status}: Shows \code{"Ok"} when photon is running without problems.
+    #'  \strong{import_date}: Time stamp when the database was built.
+    #'  \strong{version}: Photon version currently running.
+    #'  \strong{git_commit}: Git commit string of the photon version currently running.
+    #' }
+    status = function() {
+      if (self$is_ready()) {
+        query_photon("status", geojson = FALSE)
+      }
+    },
+
+    #' @description
+    #' Downloads a search index using \code{\link{download_database}}.
+    #' @param region Character string that identifies a region or country. An
+    #' extract for this region will be downloaded. If \code{"planet"}, downloads
+    #' a global extract (see note). Run \code{list_regions()} to get an overview
+    #' of available regions. You can specify countries using any code that can
+    #' be translated by \code{\link[countrycode]{countrycode}}.
+    #' @param json Extracts come in two forms: JSON dumps and pre-build databases.
+    #' Pre-built databases are more convenient but less flexible and are not available
+    #' for all regions. If you wish or need to build your own database, set
+    #' \code{json = TRUE} and use the \code{$import()} method.
+    download_data = function(region, json = FALSE) {
+      archive_path <- download_database(
+        region = region,
         path = self$path,
         quiet = private$quiet,
-        country = country,
-        date = date,
-        exact = exact,
-        section = section
+        version = private$version,
+        json = json
       )
-      untar_index(archive_path, self$path)
-      store_index_metadata(self$path, archive_path)
+
+      if (json) {
+        private$json_path <- archive_path # nocov
+      } else {
+        untar_index(archive_path, self$path)
+        store_index_metadata(self$path, archive_path)
+      }
+
       invisible(self)
     },
 
@@ -494,8 +520,9 @@ photon_local <- R6::R6Class(
     host = NULL,
     port = NULL,
     ssl = NULL,
-    country = NULL,
+    region = NULL,
     date = NULL,
+    json_path = NULL,
     opensearch = NULL,
     logs = NULL,
     finalize = function() {
@@ -506,7 +533,7 @@ photon_local <- R6::R6Class(
 
       if (!file.exists(meta_path)) {
         # if photon_data has been created outside of {photon}, metadata cannot be retrieved
-        meta <- list(country = NULL, date = NULL) # nocov
+        meta <- list(region = NULL, date = NULL) # nocov
       } else {
         meta <- readRDS(meta_path)
       }
@@ -520,7 +547,7 @@ photon_local <- R6::R6Class(
       if (!quiet) {
         cli::cli_ul(c(
           sprintf("Version: %s", meta$version),
-          sprintf("Coverage: %s", meta$country %|||% NULL),
+          sprintf("Coverage: %s", meta$region %|||% NULL),
           sprintf("Time: %s", meta$date %|||% NULL)
         ))
       }
@@ -534,10 +561,7 @@ photon_local <- R6::R6Class(
 # External ----
 setup_photon_directory <- function(path,
                                    version,
-                                   country = NULL,
-                                   date = NULL,
-                                   exact = FALSE,
-                                   section = NULL,
+                                   region = NULL,
                                    opensearch = FALSE,
                                    overwrite = FALSE,
                                    quiet = FALSE) {
@@ -557,14 +581,12 @@ setup_photon_directory <- function(path,
 
   if (!any(grepl("photon_data$", files)) || overwrite) {
     has_archive <- grepl("\\.bz2$", files)
-    if ((!any(has_archive) || overwrite) && !is.null(country)) {
+    if ((!any(has_archive) || overwrite) && !is.null(region)) {
       section <- if (opensearch) "experimental" else section
-      archive_path <- download_searchindex(
+      archive_path <- download_database(
         path = path,
-        country = country,
-        date = date,
-        exact = exact,
-        section = section,
+        region = region,
+        version = version,
         quiet = quiet
       )
     } else if (!any(has_archive)) {
@@ -593,20 +615,29 @@ untar_index <- function(archive_path, path) {
 
 
 store_index_metadata <- function(path, archive_path) {
+  # legacy file name scheme
   meta <- utils::strcapture(
     pattern = "photon-db-?([a-z]{2})?-([0-9]+|latest)\\.tar\\.bz2",
     x = basename(archive_path),
-    proto = data.frame(country = character(), date = character())
+    proto = data.frame(region = character(), date = character())
   )
 
+  if (all(is.na(meta))) {
+    meta <- utils::strcapture(
+      pattern = "photon-db-(.+)-(\\d+\\.\\d+)-([0-9]+|latest)\\.tar\\.bz2",
+      x = basename(archive_path),
+      proto = data.frame(region = character(), build_version = character(), date = character())
+    )
+  }
+
   # if a date is missing from the file name, set the current date
   meta$date <- if (identical(meta$date, "latest")) Sys.Date() else meta$date
   meta$date <- as.POSIXct(meta$date, format = "%y%m%d")
 
-  # if a country is missing from the file name, it is likely global
-  meta$country <- ifelse(
-    nzchar(meta$country),
-    countrycode::countrycode(meta$country, "iso2c", "country.name"),
+  # if a region is missing from the file name, it is likely global
+  meta$region <- ifelse(
+    nzchar(meta$region),
+    to_title(gsub("-", " ", meta$region)),
     "global"
   )
 
@@ -631,8 +662,9 @@ print.photon <- function(x, ...) {
         if (x$is_running()) cli::col_yellow("Live now!"),
         sprintf("Type     : %s", type),
         sprintf("Version  : %s (%s)", info$version, os),
-        sprintf("Coverage : %s", info$country),
-        sprintf("Time     : %s", info$date)
+        sprintf("Coverage : %s", info$region),
+        sprintf("Time     : %s", info$date),
+        sprintf("Database built for photon %s", info$build_version)
       )
     }
   )
@@ -647,7 +679,11 @@ print.photon <- function(x, ...) {
 
 construct_jar <- function(version = NULL, opensearch = FALSE) {
   version <- version %||% get_latest_photon()
-  opensearch <- ifelse(opensearch, "-opensearch", "")
+  opensearch <- ifelse(
+    opensearch & numeric_version(version) < "1.0.0",
+    "-opensearch",
+    ""
+  )
   sprintf("photon%s-%s.jar", opensearch, version)
 }
 
@@ -657,7 +693,12 @@ check_opensearch <- function(opensearch, version) {
   if (version >= "0.7.0" && !opensearch) {
     cli::cli_warn(c( # nocov start
       "!" = "ElasticSearch versions are superseded for photon 0.7.0 or higher.",
-      "i" = "You can set opensearch = TRUE, to use OpenSearch photon instead."
+      "i" = "You can set `opensearch = TRUE` to use OpenSearch instead."
+    ))
+  } else if (version >= "1.0.0" && !opensearch) {
+    cli::cli_abort(c(
+      "!" = "Since photon 1.0.0, ElasticSearch is not supported anymore.",
+      "i" = "Set `opensearch = TRUE` to use OpenSearch instead."
     )) # nocov end
   }
 }
