@@ -1,5 +1,7 @@
-query_photon <- function(endpoint, ...) {
+query_photon <- function(endpoint, ..., geojson = TRUE) {
   args <- drop_null(drop_na(list(...)))
+  is_logical <- vapply(args, is.logical, logical(1))
+  args[is_logical] <- as.numeric(args[is_logical])
   req <- httr2::request(get_photon_url())
   req <- httr2::req_template(req, "GET {endpoint}")
   req <- do.call(
@@ -20,8 +22,13 @@ query_photon <- function(endpoint, ...) {
   }
 
   resp <- httr2::req_perform(req)
-  resp <- httr2::resp_body_string(resp, encoding = "UTF-8")
-  sf::st_read(resp, as_tibble = TRUE, quiet = TRUE, drivers = "geojson")
+
+  if (geojson) {
+    resp <- httr2::resp_body_string(resp, encoding = "UTF-8")
+    sf::st_read(resp, as_tibble = TRUE, quiet = TRUE, drivers = "geojson")
+  } else {
+    httr2::resp_body_json(resp)
+  }
 }
 
 
